============
Installation
============

At the command line::

    $ pip install seismic-format

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv seismic-format
    $ pip install seismic-format
